@@ -1,5 +1,5 @@
 /* Libvoikko: Library of Finnish language tools
- * Copyright (C) 2009 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2009 - 2010 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,6 +35,10 @@ enum MalagaSymbol {
 	MS_NUMBER,
 	MS_PERSON,
 	MS_MOOD,
+	MS_VAPAA_JALKIOSA,
+	MS_NEGATIVE,
+	MS_POSSIBLE_GEOGRAPHICAL_NAME,
+	MS_REQUIRE_FOLLOWING_VERB,
 	MS_LAST_SYMBOL
 };
 
