@@ -23,6 +23,10 @@
 #include <cstdio>
 #include <cwchar>
 
+#ifdef HAVE_CONFIG_H
+  #include "config.h"
+#endif
+
 using namespace std;
 
 static const int MAX_PARAGRAPH_LENGTH = 100000;
@@ -37,6 +41,13 @@ static void printHelp() {
 	cout << "For complete descriptions of available options see 'man voikkogc'" << endl;
 }
 
+static void printVersion() {
+	#ifdef PACKAGE_VERSION
+		cout << "voikkogc version " << PACKAGE_VERSION << endl;
+	#endif
+	cout << "libvoikko version " << voikkoGetVersion() << endl;
+}
+
 static void print_tokens(VoikkoHandle * handle, const wchar_t * line, size_t lineLen) {
 	enum voikko_token_type token_type;
 	size_t tokenchars;
@@ -166,6 +177,10 @@ int main(int argc, char ** argv) {
 			printHelp();
 			exit(0);
 		}
+		else if (strcmp(argv[i],  "--version") == 0) {
+			printVersion();
+			exit(0);
+		}
 	}
 	const char * voikkoError;
 	VoikkoHandle * handle = voikkoInit(&voikkoError, variant, path);
